about summary refs log tree commit diff
diff options
context:
space:
mode:
authorGuillaume Gomez <guillaume.gomez@huawei.com>2024-02-15 11:40:22 +0100
committerGuillaume Gomez <guillaume.gomez@huawei.com>2024-02-15 14:18:19 +0100
commit0860fc14ae5b1742716f3e7719054955499ea4a7 (patch)
treeac4dea266b0b3019bbebd803b97fcbdf1e94e0de
parentbd6b3361339522cc258d1f4165e3340e4cb1add4 (diff)
downloadrust-0860fc14ae5b1742716f3e7719054955499ea4a7.tar.gz
rust-0860fc14ae5b1742716f3e7719054955499ea4a7.zip
Add clippy into the known `cfg` list
-rw-r--r--compiler/rustc_session/src/config.rs7
1 files changed, 4 insertions, 3 deletions
diff --git a/compiler/rustc_session/src/config.rs b/compiler/rustc_session/src/config.rs
index d35f951e2ae..ad9acd2e25d 100644
--- a/compiler/rustc_session/src/config.rs
+++ b/compiler/rustc_session/src/config.rs
@@ -1438,9 +1438,10 @@ impl CheckCfg {
 
         ins!(sym::debug_assertions, no_values);
 
-        // These three are never set by rustc, but we set them anyway: they
-        // should not trigger a lint because `cargo doc`, `cargo test`, and
-        // `cargo miri run` (respectively) can set them.
+        // These four are never set by rustc, but we set them anyway: they
+        // should not trigger a lint because `cargo clippy`, `cargo doc`,
+        // `cargo test` and `cargo miri run` (respectively) can set them.
+        ins!(sym::clippy, no_values);
         ins!(sym::doc, no_values);
         ins!(sym::doctest, no_values);
         ins!(sym::miri, no_values);